.. _use_tutorial:

Tutorials
=========

Getting Started
---------------

First time using :code:`stylo`? Then look no further, the following series of
tutorials will help you get to grips with stylo in no time.

- :ref:`use_tutorial_basics_1`


Advanced Tutorials
------------------

Topics covered here are not essential in order to use :code:`stylo`, however if you are
looking to dig deeper they are a great way to get to grips with some of the internals.

- :ref:`use_tutorial_domain_system`

All Tutorials
-------------

.. toctree::
   :maxdepth: 1

   basics-1
   adv-domain-system
